import codecs
import re
import os

from setuptools import setup, Command

here = os.path.abspath(os.path.dirname(__file__))


class PyTest(Command):
    user_options = []
    def initialize_options(self):
        pass
    def finalize_options(self):
        pass
    def run(self):
        import subprocess
        import sys
        errno = subprocess.call(['pytest-3'])
        raise SystemExit(errno)


def read(*parts):
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


setup(name='blockerbugs',
      version=find_version('blockerbugs', '__init__.py'),
      description='Web application for tracking blocker and nth bugs in Fedora releases',
      author='Tim Flink',
      author_email='tflink@fedoraproject.org',
      license='GPLv2+',
      url='https://pagure.io/fedora-qa/blockerbugs',
      packages=['blockerbugs', 'blockerbugs.controllers',
                'blockerbugs.util', 'blockerbugs.models',
                'blockerbugs.controllers.api',
                'blockerbugs.controllers.admin'],
      package_dir={'blockerbugs': 'blockerbugs'},
      entry_points=dict(console_scripts=['blockerbugs=blockerbugs.cli:main']),
      include_package_data=True,
      cmdclass={'test': PyTest},
      install_requires=[
            'alembic',
            'Flask-Admin',
            'Flask-SQLAlchemy',
            'Flask-WTF',
            'Flask',
            'iso8601',
            'Jinja2',
            'kitchen',
            'munch',
            'pycurl',
            'python-bugzilla',
            'python-fedora',
            'python-openid-cla',
            'python-openid-teams',
            'python3-openid',
            'SQLAlchemy',
            'Werkzeug',
            'WTForms',
      ]
)
